@@ -20,7 +20,7 @@
 #include <sipwitch/control.h>
 #include <sipwitch/mapped.h>
 
-#if defined(AF_UNIX) && !defined(_MSWINDOWS_)
+#if !defined(_MSWINDOWS_)
 #include <sys/un.h>
 #endif
 
@@ -32,8 +32,6 @@
 using namespace SIPWITCH_NAMESPACE;
 using namespace UCOMMON_NAMESPACE;
 
-#if defined(AF_UNIX) && !defined(_MSWINDOWS_)
-
 static mutex_t private_locking;
 
 class __LOCAL dispatch : public LinkedObject
@@ -106,7 +104,7 @@ void dispatch::stop(events *msg)
 
     while(is(dp)) {
         if(msg)
-            ::send(dp->session, msg, sizeof(events), 0);
+            ::send(dp->session, (const char *)msg, sizeof(events), 0);
         ::close(dp->session);
         dp.next();
     }
@@ -127,7 +125,7 @@ void dispatch::send(events *msg)
     LinkedObject *next;
     while(is(dp)) {
         next = dp->next;
-        if(::send(dp->session, msg, sizeof(events), 0) < (ssize_t)sizeof(events)) {
+        if(::send(dp->session, (const char *)msg, sizeof(events), 0) < (ssize_t)sizeof(events)) {
 disconnect:
             shell::log(DEBUG3, "releasing client events for %d", dp->session);
             dp->release();
@@ -164,6 +162,7 @@ void event_thread::run(void)
         if(client < 0)
             break;
 
+        events::sync();
         shell::log(DEBUG3, "connecting client events for %d", client);
         msg.type = events::WELCOME;
         msg.server.started = started;
@@ -172,7 +171,8 @@ void event_thread::run(void)
         String::set(msg.server.state, sizeof(msg.server.state), *saved_state);
         String::set(msg.server.realm, sizeof(msg.server.realm), *saved_realm);
         private_locking.release();
-        ::send(client, &msg, sizeof(msg), 0);
+        msg.type = events::WELCOME;
+        ::send(client, (const char *)&msg, sizeof(msg), 0);
         dispatch::add(client);
     }
 
@@ -181,31 +181,57 @@ void event_thread::run(void)
 
 bool events::start(void)
 {
-    struct sockaddr_un abuf;
-
     if(ipc != INVALID_SOCKET)
         return false;
 
+#ifdef  _MSWINDOWS_
+    struct sockaddr_in abuf;
+    ipc = ::socket(AF_INET, SOCK_STREAM, 0);
+#else
+    struct sockaddr_un abuf;
     ipc = ::socket(AF_UNIX, SOCK_STREAM, 0);
+#endif
+
     if(ipc == INVALID_SOCKET)
         return false;
 
     memset(&abuf, 0, sizeof(abuf));
+#ifdef  _MSWINDOWS_
+    abuf.sin_family = AF_INET;
+    abuf.sin_addr.s_addr = inet_addr("127.0.0.1");
+    abuf.sin_port = 0;
+    if(::bind(ipc, (struct sockaddr *)&abuf, sizeof(abuf)) < 0)
+        goto failed;
+
+    socklen_t alen = sizeof(abuf);
+    ::getsockname(ipc, (struct sockaddr *)&abuf, &alen);
+    DWORD port = ntohs(abuf.sin_port);
+    HKEY keys = HKEY_LOCAL_MACHINE, subkey;
+    if(RegCreateKeyEx(keys, "SOFTWARE\\sipwitch", 0L, NULL, REG_OPTION_NON_VOLATILE, KEY_ALL_ACCESS, NULL, &subkey, NULL) == ERROR_SUCCESS) {
+        RegSetValueEx(subkey, "port", 0L, REG_DWORD, (const BYTE *)&port, sizeof(port));
+        port = GetCurrentProcessId();
+        RegSetValueEx(subkey, "pid", 0L, REG_DWORD, (const BYTE *)&port, sizeof(port));
+        RegCloseKey(subkey);
+    }
+#else
     abuf.sun_family = AF_UNIX;
     String::set(abuf.sun_path, sizeof(abuf.sun_path), control::env("events"));
 
     ::remove(control::env("events"));
-    if(::bind(ipc, (struct sockaddr *)&abuf, SUN_LEN(&abuf)) < 0) {
-failed:
-        Socket::release(ipc);
-        return false;
-    }
+    if(::bind(ipc, (struct sockaddr *)&abuf, SUN_LEN(&abuf)) < 0)
+        goto failed;
+#endif
 
     if(::listen(ipc, 10) < 0)
         goto failed;
 
     _thread_.start();
     return true;
+
+failed:
+    Socket::release(ipc);
+    ipc = INVALID_SOCKET;
+    return false;
 }
 
 void events::connect(cdr *rec)
@@ -273,6 +299,14 @@ void events::state(const char *str)
     dispatch::send(&msg);
 }
 
+void events::sync(unsigned period)
+{
+    events msg;
+    msg.type = SYNC;
+    msg.period = period;
+    dispatch::send(&msg);
+}
+
 void events::notice(const char *reason)
 {
     events msg;
@@ -316,52 +350,4 @@ void events::terminate(const char *reason)
     ipc = INVALID_SOCKET;
 }
 
-#else
 
-bool events::start(void)
-{
-    return false;
-}
-
-void events::terminate(const char *reason)
-{
-}
-
-void events::warning(const char *reason)
-{
-}
-
-void events::failure(const char *reason)
-{
-}
-
-void events::notice(const char *reason)
-{
-}
-
-void events::activate(MappedRegistry *rr)
-{
-}
-
-void events::release(MappedRegistry *rr)
-{
-}
-
-void events::connect(cdr *rec)
-{
-}
-
-void events::drop(cdr *rec)
-{
-}
-
-void events::realm(const char *str)
-{
-}
-
-void events::state(const char *str)
-{
-}
-
-
-#endif
