@@ -16,6 +16,7 @@
 #include "sipwitch/sipwitch.h"
 #include "ucommon/secure.h"
 #ifdef _MSWINDOWS_
+#include <windows.h>
 #include <io.h>
 #else
 #include <signal.h>
@@ -24,7 +25,7 @@
 #endif
 #include <config.h>
 
-#if defined(AF_UNIX) && !defined(_MSWINDOWS_)
+#if !defined(_MSWINDOWS_)
 #include <sys/un.h>
 #endif
 
@@ -415,12 +416,16 @@ static void periodic(char **argv)
     exit(0);
 }
 
-#if defined(AF_UNIX) && !defined(_MSWINDOWS_)
 static void showevents(char **argv)
 {
+#ifdef  _MSWINDOWS_
+    socket_t ipc = ::socket(AF_INET, SOCK_STREAM, 0);
+    struct sockaddr_in addr;
+#else
     socket_t ipc = ::socket(AF_UNIX, SOCK_STREAM, 0);
     struct sockaddr_un addr;
     struct passwd *pwd = getpwuid(getuid());
+#endif
 
     if(argv[1])
         shell::errexit(1, "*** sipwitch: events: no arguments used\n");
@@ -429,6 +434,38 @@ static void showevents(char **argv)
         shell::errexit(9, "*** sipwitch: events: cannot create event socket\n");
 
     memset(&addr, 0, sizeof(addr));
+
+#ifdef  _MSWINDOWS_
+    DWORD port = 0, pid = 0;
+    DWORD plen;
+    DWORD index = 0;
+    TCHAR keyname[128];
+    TCHAR keyvalue[128];
+    DWORD size = sizeof(keyname), vsize = sizeof(keyvalue), vtype;
+    DWORD *dp;
+
+    plen = sizeof(port);
+    HKEY keys = HKEY_LOCAL_MACHINE, subkey;
+    if(RegOpenKeyEx(keys, "SOFTWARE\\sipwitch", 0, KEY_READ, &subkey) != ERROR_SUCCESS)
+        shell::errexit(10, "*** sipwitch: events: no service found\n");
+    while((RegEnumValue(subkey, index++, keyname, &size, NULL, &vtype, (BYTE *)keyvalue, &vsize) == ERROR_SUCCESS) && (vtype == REG_DWORD) && (keyname[0] != 0)) {
+        dp = (DWORD *)&keyvalue;
+        if(eq("port", keyname))
+            port = *dp;
+        else if(eq("pid", keyname))
+            pid = *dp;
+        vsize = sizeof(keyvalue);
+        size = sizeof(keyname);
+    }
+    RegCloseKey(subkey);
+    if(!port)
+        shell::errexit(10, "*** sipwitch: events: server missing\n");
+    addr.sin_family = AF_INET;
+    addr.sin_addr.s_addr = inet_addr("127.0.0.1");
+    addr.sin_port = htons((unsigned short)port);
+    if(::connect(ipc, (struct sockaddr *)&addr, sizeof(addr)) < 0)
+        shell::errexit(10, "*** sipwitch: events: server offline\n");
+#else
     addr.sun_family = AF_UNIX;
     String::set(addr.sun_path, sizeof(addr.sun_path), DEFAULT_VARPATH "/run/sipwitch/events");
     if(::connect(ipc, (struct sockaddr *)&addr, SUN_LEN(&addr)) < 0) {
@@ -441,9 +478,10 @@ static void showevents(char **argv)
         if(::connect(ipc, (struct sockaddr *)&addr, SUN_LEN(&addr)) < 0)
             shell::errexit(10, "*** sipwitch: events: server offline\n");
     }
+#endif
 
     event_t event;
-    while(::recv(ipc, &event, sizeof(event), 0) == sizeof(event)) {
+    while(::recv(ipc, (char *)&event, sizeof(event), 0) == sizeof(event)) {
         switch(event.type) {
         case events::FAILURE:
             printf("failure: %s\n", event.reason);
@@ -489,11 +527,14 @@ static void showevents(char **argv)
         case events::REALM:
             printf("changing realm to %s\n", event.server.realm);
             break;
+        case events::SYNC:
+            if(event.period)
+                printf("housekeeping period %d\n", event.period);
+            break;
         }
     }
     shell::errexit(11, "*** sipwitch: events: connection lost\n");
 }
-#endif
 
 static void dumpstats(char **argv)
 {
@@ -724,9 +765,7 @@ static void usage(void)
         "  down                     Shut down server\n"
         "  drop <user|callid>       Drop an active call\n"
         "  dump                     Dump server configuration\n"
-#if defined(AF_UNIX) && !defined(_MSWINDOWS_)
         "  events                   Display server events\n"
-#endif
         "  history [bufsize]        Set buffer or dump error log\n"
         "  ifup <iface>             Notify interface came up\n"
         "  ifdown <iface>           Notify interface went down\n"
@@ -922,10 +961,8 @@ PROGRAM_MAIN(argc, argv)
             realm(argv);
     else if(eq(*argv, "drop"))
         drop(argv);
-#if defined(AF_UNIX) && !defined(_MSWINDOWS_)
     if(eq(*argv, "events"))
         showevents(argv);
-#endif
     if(!argv[1])
         shell::errexit(1, "use: sipwitch command [arguments...]\n");
     else
